@@ -38,9 +38,9 @@ static void tabminmax_bang(t_tabminmax *x)
   t_word *vec;
 
   if (!(A = (t_garray *)pd_findbyclass(x->x_arrayname, garray_class))) {
-    error("%s: no such array", x->x_arrayname->s_name);
+    pd_error(x, "%s: no such array", x->x_arrayname->s_name);
   } else if (!garray_getfloatwords(A, &npoints, &vec)) {
-    error("%s: bad template for tabminmax", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tabminmax", x->x_arrayname->s_name);
   } else {
     int n;
     t_atom atombuf[2];
@@ -98,7 +98,7 @@ static void tabminmax_list(t_tabminmax *x, t_symbol* UNUSED(s),int argc,
     tabminmax_bang(x);
     break;
   default:
-    error("tabminmax: list must be 2 floats (is %d atoms)", argc);
+    pd_error(x, "tabminmax: list must be 2 floats (is %d atoms)", argc);
   }
 }
 
